@@ -35,8 +35,8 @@ editor window (or an encompassing DIV or PRE block in HTML), ``"selection"``,
 which is used for selected text, ``"current-line"``, which can highlight the
 current line the cursor is in in an editor.
 
-From the TextFormat returned by ``baseformat("selection")`` and ``"currentline"``, in
-most cases only the background color will be used.
+From the TextFormat returned by ``baseformat("selection")`` and
+``"current-line"``, in most cases only the background color will be used.
 
 For the roles ``"window"``, ``"selection"`` and ``"current-line"``, the
 ``baseformat()`` method also accepts a state argument, which can be
@@ -47,14 +47,9 @@ editor window based on its state (in keyboard focus or disabled). If a theme
 does not support the ``"disabled"`` and/or ``"focus"`` state, the default
 scheme is used.
 
-In the ``themes/`` directory are bundled CSS themes that can be used.
-Instantiate a bundled theme with::
+A Theme is loaded from a CSS file using::
 
     >>> from parce.theme import Theme
-    >>> th = Theme.by_name("default")
-
-To use a custom CSS theme file, load it using::
-
     >>> th = Theme('/path/to/my/custom.css')
 
 Get a TextFormat for an action, use e.g.::
@@ -63,6 +58,9 @@ Get a TextFormat for an action, use e.g.::
     >>> f
     <TextFormat color=Color(r=192, g=0, b=0, a=255)>
 
+Multiple CSS files can be combined into one theme, and CSS rules can also
+be provided as plain text when instantiating a Theme.
+
 
 Mapping actions to CSS classes
 ------------------------------
@@ -92,7 +90,6 @@ import functools
 import os
 
 from . import css
-from . import themes
 from . import util
 
 
@@ -109,40 +106,33 @@ class AbstractTheme:
 
 
 class Theme(AbstractTheme):
-    """A Theme maps a StandardAction to a TextFormat with CSS properties."""
+    """A Theme maps a StandardAction to a TextFormat with CSS properties.
 
-    def __init__(self, filename="", stylesheet=""):
-        """Instantiate Theme from a CSS file or text.
+    Zero or more ``filenames`` can be given, which are loaded after another. If
+    the ``stylesheet`` text is given, it is added to the stylesheets loaded
+    from the filename(s). (If the ``basename`` is given, it is used to resolve
+    ``@import`` rules in the ``stylesheet`` text.)
 
-        If the ``stylesheet`` text is given, it is used as the stylesheet. Only
-        if the text is empty, the filename is used to read the stylesheet from.
+    """
 
-        """
-        self._filename = filename
+    def __init__(self, *filenames, stylesheet="", basename=""):
+        """Instantiate the Theme from CSS file(s) and/or text."""
+        self._filenames = filenames
         self._css_text = stylesheet
+        self._css_base = basename
         self.TextFormat = TextFormat
 
     def __repr__(self):
         fnames = ', '.join(map(os.path.basename, self.filenames()))
         return '<{} [{}]>'.format(self.__class__.__name__, fnames)
 
-    @classmethod
-    def by_name(cls, name="default"):
-        """Create Theme by name.
-
-        The name is a CSS file in the themes/ directory, without the ".css"
-        extension.
-
-        """
-        return cls(themes.filename(name))
-
     @util.cached_property
     def _stylesheet(self):
         """Load and cache the StyleSheet."""
-        if self._css_text or not self._filename:
-            return css.StyleSheet.from_text(self._css_text, self._filename)
-        else:
-            return css.StyleSheet.from_file(self._filename)
+        sheets = [css.StyleSheet.from_file(f) for f in self._filenames]
+        if self._css_text or not self._filenames:
+            sheets.append(css.StyleSheet.from_text(self._css_text, self._css_base))
+        return sum(sheets[1:], sheets[0])
 
     @util.cached_property
     def style(self):
@@ -157,8 +147,8 @@ class Theme(AbstractTheme):
     def baseformat(self, role="window", state="default"):
         """Return a TextFormat for a specific role and a state.
 
-        The role may be any string that maps to a CSS class in the theme
-        CSS file that is available there together with the 'parce' class.
+        The ``role`` may be any string that maps to a CSS class in the theme
+        CSS file that is available there together with the ``parce`` class.
 
         The following roles are recognized and used by parce, but you may
         also define your own roles in your (applications') theme CSS files:
@@ -174,15 +164,10 @@ class Theme(AbstractTheme):
         ``"current-line"``
             The TextFormat for the current line. If you use it, set only the
             *background* color in your theme file.
-        ``"leading-whitespace"``
-            The TextFormat to highlight leading whitespace, if desired.
-        ``"trailing-whitespace"``
-            The TextFormat to highlight trailing whitespace, if desired.
-        ``"eol-marker"``
-            The *color* to draw a "end-of-line" marker with, if desired
 
         The state argument may be "default", "focus", or "disabled", and
         reflects the state of the user interface the style variant is used for.
+        If the state is "focus" or "disabled", it is added as a pseudo class.
 
         """
         if role == "window":
@@ -247,6 +232,7 @@ class TextFormat:
     """
     color = None                    #: the foreground color as Color(r, g, b, a) tuple
     background_color = None         #: the background color (id)
+    caret_color = None              #: the color for the text cursor
     text_decoration_color = None    #: the color for text decoration
     text_decoration_line = ()       #: underline, overline and/or line-through
     text_decoration_style = None    #: solid, double, dotted, dashed or wavy
@@ -283,6 +269,7 @@ class TextFormat:
         for props in (
             ('color',),
             ('background_color',),
+            ('caret_color',),
             ('text_decoration_color', 'text_decoration_line', 'text_decoration_style'),
             ('font_family',),
             ('font_kerning',),
@@ -331,6 +318,8 @@ class TextFormat:
             yield "color", css.color2hex(self.color)
         if self.background_color:
             yield "background-color", css.color2hex(self.background_color)
+        if self.caret_color:
+            yield "caret-color", css.color2hex(self.caret_color)
 
     def write_text_decoration(self):
         """Yield a text-decoration property, if set."""
@@ -385,6 +374,13 @@ class TextFormat:
     def read_background(self, values):
         self.read_background_color(values)
 
+    @_dispatch("caret-color")
+    def read_caret_color(self, values):
+        for v in values:
+            if v.color:
+                self.caret_color = v.color
+                return
+
     @_dispatch("text-decoration-color")
     def read_text_decoration_color(self, values):
         for v in values:
