@@ -21,29 +21,27 @@
 """
 This module defines the tree structure a text is parsed into.
 
-A tree consists of Context and Token objects.
+A tree consists of Context and Token objects. (Both inherit from the base
+class Node, which defines the shared methods and properties.)
 
-A Context is a list containing Tokens and other Contexts. A Context is created
-when a lexicon becomes active. A Context knows its parent Context and its
-lexicon.
+A :class:`Context` is a list containing Tokens and other Contexts. A Context is
+created when a lexicon becomes active. A Context knows its parent Context and
+its lexicon.
 
-A Token represents one parsed piece of text. A Token is created when a rule in
-the lexicon matches. A Token knows its parent Context, its position in the text
-and the action that was specified in the rule.
+A :class:`Token` represents one parsed piece of text. A Token is created when a
+rule in the lexicon matches. A Token knows its parent Context, its position in
+the text and the action that was specified in the rule.
 
-The root Context is always one, and it represents the root lexicon. A Context
-is always non-empty, except for the root Context, which is empty if the
-document did not generate a single token.
+A Context is always non-empty, except for the root Context, which represents
+the root lexicon and can be empty if the document did not generate a single
+token.
 
-The tree structure is very easy to navigate, no special objects or iterators
-are necessary for that.
-
-To find a token at a certain position in a context, use find_token() and its
-relatives. From every token you can iterate forward() and backward(). Use the
-methods like left_siblings() and right_siblings() to traverse the current
-context.
-
-See also the documentation for Token and Context.
+The tree structure is easy to navigate, no special objects or iterators are
+necessary for that. To find a token at a certain position in a context, use
+:meth:`Context.find_token` and its relatives. From every node you can iterate
+:meth:`~Node.forward` and :meth:`~Node.backward`. Use the methods like
+:meth:`~Node.left_siblings` and :meth:`~Node.right_siblings` to traverse the
+current context.
 
 """
 
@@ -823,7 +821,15 @@ class Context(list, Node):
     def find_token_with_trail(self, pos):
         """Return the Token at or to the right of position, and the trail of indices.
 
-        Returns (None, None) if there is no such token.
+        The trail is the list of indices where the token was found. Returns
+        (None, None) if there is no such token. Here is an example::
+
+            >>> import parce
+            >>> tree = parce.root(parce.find('css'), open('parce/themes/default.css').read())
+            >>> tree.find_token_with_trail(600)
+            (<Token ' Selected te...ow has focus ' at 566:607 (Comment)>, [21, 0])
+            >>> tree[21][0]
+            <Token ' Selected te...ow has focus ' at 566:607 (Comment)>
 
         """
         i = self.find(pos)
@@ -1040,7 +1046,7 @@ class Context(list, Node):
 def make_tokens(event, parent=None):
     """Factory returning a tuple of one or more Token instances for the event.
 
-    The event is an Event namedtuple defined in the mod:`~parce.lexer` module.
+    The event is an Event namedtuple defined in the :mod:`~parce.lexer` module.
     If the event contains more than one lexeme, GroupToken instances are
     created.
 
