@@ -26,7 +26,6 @@ This module only depends on the Python standard library.
 """
 
 import bisect
-import re
 import codecs
 import contextlib
 import functools
@@ -441,22 +440,56 @@ class Switch:
         return s
 
 
-class Symbol:
-    """An unique object that has a name."""
-    __slots__ = ('_name_',)
-    _store_ = {}
-    _lock_ = threading.Lock()
-    def __new__(cls, name):
-        with cls._lock_:
-            try:
-                obj = cls._store_[name]
-            except KeyError:
-                obj = cls._store_[name] = object.__new__(cls)
-                obj._name_ = name
-            return obj
+def object_locker():
+    """Return a callable that can hold a lock on an object.
 
-    def __repr__(self):
-        return self._name_
+    The Lock is automatically created when requested for the first time, and
+    deleted when released for the last time. Keeps a reference to the object
+    until the last lock is released.
+
+    Usage example::
+
+        >>> lock = object_locker()
+        >>> with lock(obj):
+        ...     do_something()
+
+    The lock callable should remain alive as long as the object is alive, so it
+    is reused; it is the context where the locking is active. This function is
+    an alternative to::
+
+        >>> class Object:
+        ...     def __init__(self):
+        ...         self._lock = threading.Lock()
+        ...
+        >>> o = Object()
+
+    and then later::
+
+        >>> with o._lock:
+        ...     do_something()
+
+    In this use case the allocated Lock lives as long as the object, which
+    might not be desirable if you have a large amount of objects of this type.
+
+    """
+    locker = {}
+    locker_lock = threading.Lock()
+
+    def lock_object(obj):
+        with locker_lock:
+            try:
+                return locker[obj]
+            except KeyError:
+                lock = locker[obj] = threading.Lock()
+                @contextlib.contextmanager
+                def cleanup():
+                    try:
+                        with lock:
+                            yield
+                    finally:
+                        del locker[obj]
+                return cleanup()
+    return lock_object
 
 
 def cached_method(func):
@@ -467,29 +500,17 @@ def cached_method(func):
     instance.
 
     """
-    _cache = weakref.WeakKeyDictionary()
-    _locker = weakref.WeakKeyDictionary()
-    _lock = threading.Lock()
-
-    def lock(obj):
-        with _lock:
-            try:
-                return _locker[obj]
-            except KeyError:
-                lock = _locker[obj] = threading.Lock()
-                return lock
+    lock = object_locker()
+    cache = weakref.WeakKeyDictionary()
 
     @functools.wraps(func)
     def wrapper(self, *args):
-        try:
-            return _cache[self][args]
-        except KeyError:
-            with lock(self):
-                try:
-                    return _cache[self][args]
-                except KeyError:
-                    v = _cache.setdefault(self, {})[args] = func(self, *args)
-                    return v
+        with lock(self):
+            try:
+                return cache[self][args]
+            except KeyError:
+                v = cache.setdefault(self, {})[args] = func(self, *args)
+                return v
     return wrapper
 
 
@@ -505,22 +526,57 @@ def cached_func(func):
     supported. The cache is thread-safe.
 
     """
-    _cache = {}
-    _lock =threading.Lock()
+    cache = caching_dict(func, True)
     @functools.wraps(func)
     def wrapper(*args):
-        try:
-            return _cache[args]
-        except KeyError:
-            with _lock:
-                try:
-                    return _cache[args]
-                except KeyError:
-                    v = _cache[args] = func(*args)
-                    return v
+        return cache[args]
     return wrapper
 
 
+def caching_dict(func, unpack=False):
+    """Create a dict with a thread-safe factory function for missing keys.
+
+    When a key is not present, the factory function is called. The difference
+    with :class:`collections.defaultdict` is that the factory function is
+    called with the key as argument, or, if ``unpack`` is set to True, with the
+    key arguments unpacked. Built-in locking makes sure another thread cannot
+    call the factory function at the same time.
+
+    """
+    lock = threading.Lock()
+
+    class cache(dict):
+        if unpack:
+            def __getitem__(self, key):
+                with lock:
+                    try:
+                        return super().__getitem__(key)
+                    except KeyError:
+                        value = self[key] = func(*key)
+                        return value
+        else:
+            def __getitem__(self, key):
+                with lock:
+                    try:
+                        return super().__getitem__(key)
+                    except KeyError:
+                        value = self[key] = func(key)
+                        return value
+    return cache()
+
+
+class Symbol:
+    """An unique object that has a name; the same name returns the same object."""
+    def __repr__(self):
+        return self._name
+
+    @cached_func
+    def __new__(cls, name):
+        obj = object.__new__(cls)
+        obj._name = name
+        return obj
+
+
 def fix_boundaries(stream, start, end):
     """Yield all items from the stream of tuples.
 
@@ -629,11 +685,6 @@ def split_list(l, separator):
         i = j + 1
 
 
-def quote(s):
-    """Like repr, but return s with double quotes, escaping " and \\."""
-    return '"' + re.sub(r'([\\"])', r'\\\1', s) + '"'
-
-
 def tokens(nodes):
     """Helper to yield tokens from the iterable of nodes."""
     for n in nodes:
